# EmailV30

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**created_date** | [**CreatedDateV30**](CreatedDateV30.md) |  | [optional] 
**last_modified_date** | [**LastModifiedDateV30**](LastModifiedDateV30.md) |  | [optional] 
**source** | [**SourceV30**](SourceV30.md) |  | [optional] 
**email** | **str** |  | [optional] 
**path** | **str** |  | [optional] 
**visibility** | **str** |  | [optional] 
**verified** | **bool** |  | [optional] 
**primary** | **bool** |  | [optional] 
**put_code** | **int** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

